# keystore/truststore paths
INCLUSTER_KEYSTORE_PATH = "/etc/nsxi/store/keystore.p12"
INCLUSTER_TRUSTSTORE_PATH = "/etc/nsxi/store/truststore.p12"
INCLUSTER_CA_PATH = "/etc/nsxi/store/ca.crt"
EGRESS_KEYSTORE_PATH = "/etc/nsxi/store/egress-keystore.p12"

# limits/requirements
NUM_TRANSPORT_NODE_LIMIT = 250

VALID_LICENSE_LIST = [
    "NSX Data Center Enterprise Plus",
    "NSX Data Center Evaluation",
    "NSX-T Enterprise Plus",
    "NSX-T Evaluation",
    "NSX Firewall",
    "NSX Firewall with Advanced Threat Prevention",
    "NSX Firewall with Baremetal",
    "NSX Firewall Evaluation",
    "NSX Data Center SP Base",
    "NSX Data Center SP Professional",
    "NSX Data Center SP Advanced",
    "NSX Data Center SP Enterprise Plus",
    "NSX Distributed Firewall",
    "NSX Distributed Firewall with Threat Prevention",
    "NSX Distributed Firewall with Advanced Threat Prevention",
    "NSX Gateway Firewall-VM",
    "NSX Gateway Firewall with Threat Prevention - VM",
    "NSX Gateway Firewall with Advanced Threat Prevention - VM",
    "NSX Gateway Firewall - ISO",
    "NSX Gateway Firewall with Threat Prevention - ISO",
    "NSX Gateway Firewall with Advanced Threat Prevention - ISO",
    "VMware Container Networking with Antrea Enterprise"
]

VALID_COMBO_LICENSE_LIST = [
    # combos with "NSX Advanced Threat Prevention"
    ["NSX Data Center Advanced", "NSX Advanced Threat Prevention"],
    ["NSX-T Advanced", "NSX Advanced Threat Prevention"],
    # combos with "NSX Advanced Threat Prevention Add On for ..."
    ["NSX Data Center Advanced",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX-T Advanced",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX Data Center Advanced", "NSX Threat Prevention Add On for NSX Distributed Firewall"],
    ["NSX-T Advanced", "NSX Threat Prevention Add On for NSX Distributed Firewall"]

]

ADVANCED_LICENSE_LIST = [
    "NSX Data Center Evaluation",
    "NSX Distributed Firewall with Advanced Threat Prevention",
    "NSX Firewall with Advanced Threat Prevention",
    "NSX-T Evaluation"
]

ADVANCED_COMBO_LICENSE_LIST = [
    # combos with "NSX Advanced Threat Prevention"
    ["NSX Data Center Advanced", "NSX Advanced Threat Prevention"],
    ["NSX Data Center Enterprise Plus", "NSX Advanced Threat Prevention"],
    ["NSX Distributed Firewall", "NSX Advanced Threat Prevention"],
    ["NSX-T Advanced", "NSX Advanced Threat Prevention"],
    ["NSX-T Enterprise Plus", "NSX Advanced Threat Prevention"],
    # combos with "NSX Advanced Threat Prevention Add On for ..."
    ["NSX Data Center Advanced",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX Data Center Enterprise Plus",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX Distributed Firewall",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX-T Advanced",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    ["NSX-T Enterprise Plus",
     "NSX Advanced Threat Prevention Add On for NSX Distributed Firewall, NSX DC Advanced, NSX DC Enterprise Plus"],
    # combos with "NSX Threat Prevention Add On."
    ["NSX Data Center Enterprise Plus", "NSX Threat Prevention Add On for NSX Distributed Firewall"],
    ["NSX-T Enterprise Plus", "NSX Threat Prevention Add On for NSX Distributed Firewall"],
    ["NSX Data Center Advanced", "NSX Threat Prevention Add On for NSX Distributed Firewall"],
    ["NSX-T Advanced", "NSX Threat Prevention Add On for NSX Distributed Firewall"],
    ["NSX Distributed Firewall", "NSX Threat Prevention Add On for NSX Distributed Firewall"]
]

# REST headers
BASE_HEADERS = {'Content-Type': 'application/json'}
RBAC_IN_CLUSTER_HEADER = {'x-nsx-roles': 'ZW50ZXJwcmlzZV9hZG1pbgo='}

# API endpoints/hosts
CLUSTER_API_HOST = "cluster-api"
MONITOR_API_HOST = "monitor"
NSX_MANAGER_HOST = "external-nsx-manager"


class PlatformFormFactor:
    ADVANCED = "advanced"
    STANDARD = "standard"
    EVALUATION = "evaluation"


class Feature:
    INTELLIGENCE = "intelligence"


# Precheck Plugins
class PrecheckPlugin:
    LICENSE = "license"
    TRANSPORT_NODES = "transport_nodes"
    PLATFORM_TYPE = "platform_type"
    ADVANCED_LICENSE = "advanced_license"


class CheckStatus:
    SUCCESS = "SUCCESS"
    FAILED = "FAILED"
    WARNING = "WARNING"
    SKIPPED = "SKIPPED"
    INPROGRESS = "INPROGRESS"
    STOPPING = "STOPPING"
    STOPPED = "STOPPED"


class Url:
    class InCluster:
        POST_REGISTER_UI_PLUGIN = "https://{service_host}:{service_port}/post-deployment"
        POST_REPORT_PRECHECK = "https://{service_host}:{service_port}/report/precheck"
        GET_PLATFORM_STATUS = "https://{service_host}:{service_port}/api/v1/platform/monitor/platform/status"
        GET_FEATURE_INTEL_CONFIG = "https://{service_host}:{service_port}/features/intelligence/config"

    class Egress:
        GET_TRANSPORT_NODES = "https://{service_host}:443/api/v1/transport-nodes".format(
            service_host=NSX_MANAGER_HOST)
        GET_LICENSE_ALL = "https://{service_host}:443/api/v1/licenses".format(
            service_host=NSX_MANAGER_HOST)
        GET_CLUSTER_REGISTRATION = (
            "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration"
            .format(service_host=NSX_MANAGER_HOST))
        PATCH_CLUSTER_REGISTRATION = (
            "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration/{cluster_id}")
